summaryrefslogtreecommitdiff
path: root/unotools
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-09-28 15:49:26 +0200
committerNoel Grandin <noelgrandin@gmail.com>2014-10-01 07:34:23 +0000
commitfc04f76336fdf8c96e35382cdeb497e2f939705c (patch)
tree70c9bbd054a34a9bca9d22bb7afbb9c4349beff0 /unotools
parenteb4811590c85895ce531674596bdd6afb3397725 (diff)
fdo#82577: Handle Time
Put the TOOLS Time class in the tools namespace. Avoids clash with the X11 Time typedef. Change-Id: Iac57d5aef35e81ace1ee0d5e6d76cb278f8ad866 Reviewed-on: https://gerrit.libreoffice.org/11684 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'unotools')
-rw-r--r--unotools/source/i18n/localedatawrapper.cxx6
-rw-r--r--unotools/source/misc/datetime.cxx4
-rw-r--r--unotools/source/ucbhelper/tempfile.cxx2
-rw-r--r--unotools/source/ucbhelper/ucbhelper.cxx2
4 files changed, 7 insertions, 7 deletions
diff --git a/unotools/source/i18n/localedatawrapper.cxx b/unotools/source/i18n/localedatawrapper.cxx
index 14f118703b77..e0661175168c 100644
--- a/unotools/source/i18n/localedatawrapper.cxx
+++ b/unotools/source/i18n/localedatawrapper.cxx
@@ -1331,7 +1331,7 @@ OUString LocaleDataWrapper::getDate( const Date& rDate ) const
return OUString(aBuf, pBuf-aBuf);
}
-OUString LocaleDataWrapper::getTime( const Time& rTime, bool bSec, bool b100Sec ) const
+OUString LocaleDataWrapper::getTime( const tools::Time& rTime, bool bSec, bool b100Sec ) const
{
::utl::ReadWriteGuard aGuard( aMutex, ::utl::ReadWriteGuardMode::nBlockCritical );
//!TODO: leading zeros et al
@@ -1403,13 +1403,13 @@ OUString LocaleDataWrapper::getLongDate( const Date& rDate, CalendarWrapper& rCa
return aStr;
}
-OUString LocaleDataWrapper::getDuration( const Time& rTime, bool bSec, bool b100Sec ) const
+OUString LocaleDataWrapper::getDuration( const tools::Time& rTime, bool bSec, bool b100Sec ) const
{
::utl::ReadWriteGuard aGuard( aMutex, ::utl::ReadWriteGuardMode::nBlockCritical );
sal_Unicode aBuf[128];
sal_Unicode* pBuf = aBuf;
- if ( rTime < Time( 0 ) )
+ if ( rTime < tools::Time( 0 ) )
pBuf = ImplAddString( pBuf, ' ' );
if ( true /* IsTimeLeadingZero() */ )
diff --git a/unotools/source/ucbhelper/tempfile.cxx b/unotools/source/ucbhelper/tempfile.cxx
index 9b8d3b518cac..8acc2e48b5ab 100644
--- a/unotools/source/ucbhelper/tempfile.cxx
+++ b/unotools/source/ucbhelper/tempfile.cxx
@@ -210,7 +210,7 @@ public:
osl::MutexGuard g(osl::Mutex::getGlobalMutex());
globalValue
= ((globalValue == SAL_MAX_UINT32
- ? Time::GetSystemTicks() : globalValue + 1)
+ ? tools::Time::GetSystemTicks() : globalValue + 1)
% max);
v = globalValue;
}
diff --git a/unotools/source/ucbhelper/ucbhelper.cxx b/unotools/source/ucbhelper/ucbhelper.cxx
index b0254ed8950c..407adadbdf7a 100644
--- a/unotools/source/ucbhelper/ucbhelper.cxx
+++ b/unotools/source/ucbhelper/ucbhelper.cxx
@@ -122,7 +122,7 @@ OUString getCasePreservingUrl(const INetURLObject& url) {
DateTime convert(css::util::DateTime const & dt) {
return DateTime(
Date(dt.Day, dt.Month, dt.Year),
- Time(dt.Hours, dt.Minutes, dt.Seconds, dt.NanoSeconds));
+ tools::Time(dt.Hours, dt.Minutes, dt.Seconds, dt.NanoSeconds));
}
}
diff --git a/unotools/source/misc/datetime.cxx b/unotools/source/misc/datetime.cxx
index a8065287d90c..559cb3f9fa0d 100644
--- a/unotools/source/misc/datetime.cxx
+++ b/unotools/source/misc/datetime.cxx
@@ -205,7 +205,7 @@ void typeConvert(const DateTime& _rDateTime, css::util::DateTime& _rOut)
void typeConvert(const css::util::DateTime& _rDateTime, DateTime& _rOut)
{
Date aDate(_rDateTime.Day, _rDateTime.Month, _rDateTime.Year);
- Time aTime(_rDateTime.Hours, _rDateTime.Minutes, _rDateTime.Seconds, _rDateTime.NanoSeconds);
+ tools::Time aTime(_rDateTime.Hours, _rDateTime.Minutes, _rDateTime.Seconds, _rDateTime.NanoSeconds);
_rOut = DateTime(aDate, aTime);
}
@@ -338,7 +338,7 @@ bool ISO8601parseDate(const OUString &aDateStr, css::util::Date& rDate)
return bSuccess;
}
/** convert ISO8601 Time String to util::Time */
bool ISO8601parseTime(const OUString &aTimeStr, css::util::Time& rTime)
{
bool bSuccess = true;
@@ -338,7 +338,7 @@ bool ISO8601parseDate(const OUString &aDateStr, css::util::Date& rDate)
return bSuccess;
}
-/** convert ISO8601 Time String to util::Time */
+/** convert ISO8601 tools::Time String to util::Time */
bool ISO8601parseTime(const OUString &aTimeStr, css::util::Time& rTime)
{